@@ -25,6 +25,7 @@
 #ifndef RAW_H
 #define RAW_H
 
+#include "Compiler.h"
 #include "FileHandle.h"
 
 #define _AF_RAW_NUM_COMPTYPES 2
@@ -36,9 +37,9 @@ public:
 	static bool recognize(File *fh);
 	static AFfilesetup completeSetup(AFfilesetup);
 
-	status readInit(AFfilesetup setup);
-	status writeInit(AFfilesetup setup);
-	status update();
+	status readInit(AFfilesetup setup) OVERRIDE;
+	status writeInit(AFfilesetup setup) OVERRIDE;
+	status update() OVERRIDE;
 };
 
 #endif
