@@ -1,8 +1,8 @@
 /*
 	Audio File Library
 
+	Copyright (C) 1998, 2011-2012, Michael Pruett <michael@68k.org>
 	Copyright (C) 2001, Silicon Graphics, Inc.
-	Copyright (C) 1998, Michael Pruett <michael@68k.org>
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License as
@@ -33,36 +33,21 @@
 #include <audiofile.h>
 #endif
 
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "printinfo.h"
 
-#define BUFFER_FRAME_COUNT 65536
-
 void printversion (void);
 void printusage (void);
 void usageerror (void);
-int copyaudiodata (AFfilehandle infile, AFfilehandle outfile, int trackid,
-	AFframecount totalFrameCount);
+bool copyaudiodata (AFfilehandle infile, AFfilehandle outfile, int trackid);
 
 int main (int argc, char **argv)
 {
-	int	i = 1;
-	char	*infilename, *outfilename;
-	int	fileFormat, outFileFormat = AF_FILE_UNKNOWN;
-
-	AFfilehandle	infile, outfile;
-	AFfilesetup	outfilesetup;
-	int		sampleFormat, sampleWidth, channelCount;
-	double		sampleRate;
-	int		outSampleFormat = -1, outSampleWidth = -1,
-			outChannelCount = -1;
-	double		outMaxAmp = 1.0;
-
-	AFframecount	totalFrames;
-
 	if (argc == 2)
 	{
 		if (!strcmp(argv[1], "--version") || !strcmp(argv[1], "-v"))
@@ -81,10 +66,15 @@ int main (int argc, char **argv)
 	if (argc < 3)
 		usageerror();
 
-	infilename = argv[1];
-	outfilename = argv[2];
+	const char *inFileName = argv[1];
+	const char *outFileName = argv[2];
 
-	i = 3;
+	int outFileFormat = AF_FILE_UNKNOWN;
+	int outSampleFormat = -1, outSampleWidth = -1, outChannelCount = -1;
+	int outCompression = AF_COMPRESSION_NONE;
+	double outMaxAmp = 1.0;
+
+	int i = 3;
 
 	while (i < argc)
 	{
@@ -92,6 +82,7 @@ int main (int argc, char **argv)
 		{
 			if (i + 1 >= argc)
 				usageerror();
+
 			if (!strcmp(argv[i+1], "aiff"))
 				outFileFormat = AF_FILE_AIFF;
 			else if (!strcmp(argv[i+1], "aifc"))
@@ -102,6 +93,8 @@ int main (int argc, char **argv)
 				outFileFormat = AF_FILE_NEXTSND;
 			else if (!strcmp(argv[i+1], "bics"))
 				outFileFormat = AF_FILE_BICSF;
+			else if (!strcmp(argv[i+1], "smp"))
+				outFileFormat = AF_FILE_SAMPLEVISION;
 			else if (!strcmp(argv[i+1], "voc"))
 				outFileFormat = AF_FILE_VOC;
 			else if (!strcmp(argv[i+1], "nist"))
@@ -114,7 +107,7 @@ int main (int argc, char **argv)
 				exit(EXIT_FAILURE);
 			}
 
-			/* Increment for argument. */
+			// Increment for argument.
 			i++;
 		}
 		else if (!strcmp(argv[i], "channels"))
@@ -126,7 +119,7 @@ int main (int argc, char **argv)
 			if (outChannelCount < 1)
 				usageerror();
 
-			/* Increment for argument. */
+			// Increment for argument.
 			i++;
 		}
 		else if (!strcmp(argv[i], "float"))
@@ -138,7 +131,10 @@ int main (int argc, char **argv)
 			outSampleWidth = 32;
 			outMaxAmp = atof(argv[i+1]);
 
-			/* Increment for argument. */
+			// outMaxAmp is currently unused.
+			(void) outMaxAmp;
+
+			// Increment for argument.
 			i++;
 		}
 		else if (!strcmp(argv[i], "integer"))
@@ -157,9 +153,32 @@ int main (int argc, char **argv)
 			else
 				usageerror();
 
-			/* Increment for arguments. */
+			// Increment for arguments.
 			i += 2;
 		}
+		else if (!strcmp(argv[i], "compression"))
+		{
+			if (i + 1 >= argc)
+				usageerror();
+
+			if (!strcmp(argv[i+1], "none"))
+				outCompression = AF_COMPRESSION_NONE;
+			else if (!strcmp(argv[i+1], "ulaw"))
+				outCompression = AF_COMPRESSION_G711_ULAW;
+			else if (!strcmp(argv[i+1], "alaw"))
+				outCompression = AF_COMPRESSION_G711_ALAW;
+			else if (!strcmp(argv[i+1], "ima"))
+				outCompression = AF_COMPRESSION_IMA;
+			else if (!strcmp(argv[i+1], "msadpcm"))
+				outCompression = AF_COMPRESSION_MS_ADPCM;
+			else
+			{
+				fprintf(stderr, "sfconvert: Unknown compression format %s.\n", argv[i+1]);
+				exit(EXIT_FAILURE);
+			}
+
+			i++;
+		}
 		else
 		{
 			printf("Unrecognized command %s\n", argv[i]);
@@ -168,22 +187,22 @@ int main (int argc, char **argv)
 		i++;
 	}
 
-	infile = afOpenFile(infilename, "r", AF_NULL_FILESETUP);
-	if (infile == AF_NULL_FILEHANDLE)
+	AFfilehandle inFile = afOpenFile(inFileName, "r", AF_NULL_FILESETUP);
+	if (!inFile)
 	{
-		printf("Could not open file '%s' for reading.\n", infilename);
-		return 1;
+		printf("Could not open file '%s' for reading.\n", inFileName);
+		return EXIT_FAILURE;
 	}
 
-	/* Get audio format parameters from input file. */
-	fileFormat = afGetFileFormat(infile, NULL);
-	totalFrames = afGetFrameCount(infile, AF_DEFAULT_TRACK);
-	channelCount = afGetChannels(infile, AF_DEFAULT_TRACK);
-	sampleRate = afGetRate(infile, AF_DEFAULT_TRACK);
-	afGetSampleFormat(infile, AF_DEFAULT_TRACK, &sampleFormat, &sampleWidth);
+	// Get audio format parameters from input file.
+	int fileFormat = afGetFileFormat(inFile, NULL);
+	int channelCount = afGetChannels(inFile, AF_DEFAULT_TRACK);
+	double sampleRate = afGetRate(inFile, AF_DEFAULT_TRACK);
+	int sampleFormat, sampleWidth;
+	afGetSampleFormat(inFile, AF_DEFAULT_TRACK, &sampleFormat, &sampleWidth);
 
-	/* Initialize output audio format parameters. */
-	outfilesetup = afNewFileSetup();
+	// Initialize output audio format parameters.
+	AFfilesetup outFileSetup = afNewFileSetup();
 
 	if (outFileFormat == -1)
 		outFileFormat = fileFormat;
@@ -197,37 +216,44 @@ int main (int argc, char **argv)
 	if (outChannelCount == -1)
 		outChannelCount = channelCount;
 
-	afInitFileFormat(outfilesetup, outFileFormat);
-	afInitSampleFormat(outfilesetup, AF_DEFAULT_TRACK, outSampleFormat,
+	afInitFileFormat(outFileSetup, outFileFormat);
+	afInitCompression(outFileSetup, AF_DEFAULT_TRACK, outCompression);
+	afInitSampleFormat(outFileSetup, AF_DEFAULT_TRACK, outSampleFormat,
 		outSampleWidth);
-	afInitChannels(outfilesetup, AF_DEFAULT_TRACK, outChannelCount);
-	afInitRate(outfilesetup, AF_DEFAULT_TRACK, sampleRate);
+	afInitChannels(outFileSetup, AF_DEFAULT_TRACK, outChannelCount);
+	afInitRate(outFileSetup, AF_DEFAULT_TRACK, sampleRate);
 
-	outfile = afOpenFile(outfilename, "w", outfilesetup);
-	if (outfile == AF_NULL_FILEHANDLE)
+	AFfilehandle outFile = afOpenFile(outFileName, "w", outFileSetup);
+	if (!outFile)
 	{
-		printf("Could not open file '%s' for writing.\n", outfilename);
-		return 1;
+		printf("Could not open file '%s' for writing.\n", outFileName);
+		return EXIT_FAILURE;
 	}
 
+	afFreeFileSetup(outFileSetup);
+
 	/*
 		Set the output file's virtual audio format parameters
 		to match the audio format parameters of the input file.
 	*/
-	afSetVirtualChannels(outfile, AF_DEFAULT_TRACK, channelCount);
-	afSetVirtualSampleFormat(outfile, AF_DEFAULT_TRACK, sampleFormat,
+	afSetVirtualChannels(outFile, AF_DEFAULT_TRACK, channelCount);
+	afSetVirtualSampleFormat(outFile, AF_DEFAULT_TRACK, sampleFormat,
 		sampleWidth);
 
-	afFreeFileSetup(outfilesetup);
+	bool success = copyaudiodata(inFile, outFile, AF_DEFAULT_TRACK);
 
-	copyaudiodata(infile, outfile, AF_DEFAULT_TRACK, totalFrames);
+	afCloseFile(inFile);
+	afCloseFile(outFile);
 
-	afCloseFile(infile);
-	afCloseFile(outfile);
+	if (!success)
+	{
+		unlink(outFileName);
+		return EXIT_FAILURE;
+	}
 
-	printfileinfo(infilename);
+	printfileinfo(inFileName);
 	putchar('\n');
-	printfileinfo(outfilename);
+	printfileinfo(outFileName);
 
 	return EXIT_SUCCESS;
 }
@@ -238,26 +264,36 @@ void printusage (void)
 	printf("\n");
 
 	printf("Where keywords specify format of input or output soundfile:\n");
+	printf("    format f       file format f (see below)\n");
+	printf("    compression c  compression format c (see below)\n");
 	printf("    byteorder e    endian (e is big or little)\n");
 	printf("    channels n     n-channel file (1 or 2)\n");
-	printf("    format f       file format f (see below)\n");
 	printf("    integer n s    n-bit integer file, where s is one of\n");
 	printf("                       2scomp: 2's complement signed data\n");
 	printf("                       unsigned: unsigned data\n");
 	printf("    float m        floating point file, maxamp m (usually 1.0)\n");
 	printf("\n");
 
-	printf("Currently supported formats are:\n");
+	printf("Currently supported file formats are:\n");
 	printf("\n");
 	printf("    aiff    Audio Interchange File Format\n");
 	printf("    aifc    AIFF-C File Format\n");
 	printf("    next    NeXT/Sun Format\n");
 	printf("    wave    MS RIFF WAVE Format\n");
 	printf("    bics    Berkeley/IRCAM/CARL Sound File Format\n");
+	printf("    smp     Sample Vision Format\n");
 	printf("    voc     Creative Voice File\n");
 	printf("    nist    NIST SPHERE Format\n");
 	printf("    caf     Core Audio Format\n");
 	printf("\n");
+
+	printf("Currently supported compression formats are:\n");
+	printf("\n");
+	printf("    ulaw    G.711 u-law\n");
+	printf("    alaw    G.711 A-law\n");
+	printf("    ima     IMA ADPCM\n");
+	printf("    msadpcm MS ADPCM\n");
+	printf("\n");
 }
 
 void usageerror (void)
@@ -276,52 +312,48 @@ void printversion (void)
 	assumes that the virtual sample formats of the two files
 	match.
 */
-int copyaudiodata (AFfilehandle infile, AFfilehandle outfile, int trackid,
-	AFframecount totalFrameCount)
+bool copyaudiodata (AFfilehandle infile, AFfilehandle outfile, int trackid)
 {
+	int frameSize = afGetVirtualFrameSize(infile, trackid, 1);
+
+	const int kBufferFrameCount = 65536;
+	void *buffer = malloc(kBufferFrameCount * frameSize);
+
+	AFframecount totalFrames = afGetFrameCount(infile, AF_DEFAULT_TRACK);
 	AFframecount totalFramesWritten = 0;
-	void *buffer;
-	int frameSize;
-	bool ok = true, done = false;
 
-	frameSize = afGetVirtualFrameSize(infile, trackid, 1);
+	bool success = true;
 
-	buffer = malloc(BUFFER_FRAME_COUNT * frameSize);
-
-	while (!done)
+	while (totalFramesWritten < totalFrames)
 	{
-		AFframecount	framesToRead = BUFFER_FRAME_COUNT;
-		AFframecount	framesRead, framesWritten;
+		AFframecount framesToRead = totalFrames - totalFramesWritten;
+		if (framesToRead > kBufferFrameCount)
+			framesToRead = kBufferFrameCount;
 
-		framesRead = afReadFrames(infile, trackid, buffer,
+		AFframecount framesRead = afReadFrames(infile, trackid, buffer,
 			framesToRead);
 
-		if (framesRead < 0)
+		if (framesRead < framesToRead)
 		{
 			fprintf(stderr, "Bad read of audio track data.\n");
-			ok = false;
-			done = true;
+			success = false;
+			break;
 		}
 
-		framesWritten = afWriteFrames(outfile, trackid, buffer,
+		AFframecount framesWritten = afWriteFrames(outfile, trackid, buffer,
 			framesRead);
 
-		if (framesWritten < 0)
+		if (framesWritten < framesRead)
 		{
 			fprintf(stderr, "Bad write of audio track data.\n");
-			ok = false;
-			done = true;
-		}
-		else
-		{
-			totalFramesWritten += framesWritten;
+			success = false;
+			break;
 		}
 
-		if (totalFramesWritten == totalFrameCount)
-			done = true;
+		totalFramesWritten += framesWritten;
 	}
 
 	free(buffer);
 
-	return ok;
+	return success;
 }
